@@ -8,7 +8,7 @@ use Data::MARC::Validator::Report::Error 0.02;
 use Data::MARC::Validator::Report::Plugin::Errors 0.02;
 use MARC::Validator::Utils qw(check_260c_year);
 
-our $VERSION = 0.10;
+our $VERSION = 0.11;
 
 sub module_name {
 	my $self = shift;
@@ -39,8 +39,7 @@ sub process {
 	if (@record_errors) {
 		push @{$self->{'errors'}},  Data::MARC::Validator::Report::Plugin::Errors->new(
 			'errors' => \@record_errors,
-			# TODO process
-			'filters' => [],
+			'filters' => $self->{'filters'},
 			'record_id' => $record_id,
 		);
 	}
